==> vtigercrm-5.3.0p0.tgz: modules/Potentials/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Potentials/language/en_us.lang.php,v 1.18 2005/04/28 14:05:53 ray Exp $
 * Description:  Defines the English language pack for the Account module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese|30/12/2010|Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Oportunidades',
'LBL_MODULE_TITLE'=>'Oportunidades: Principal',
'LBL_SEARCH_FORM_TITLE'=>'Pesquisar Oportunidade',
'LBL_LIST_FORM_TITLE'=>'Listar Oportunidade',
'LBL_OPPORTUNITY_NAME'=>'Nome Oportunidade:',
'LBL_OPPORTUNITY'=>'Oportunidade:',
'LBL_NAME'=>'Nome Oportunidade',
'LBL_INVITEE'=>'Contatos',
'LBL_LIST_OPPORTUNITY_NAME'=>'Oportunidade',
'LBL_LIST_ACCOUNT_NAME'=>'Nome Conta',
'LBL_PRODUCT_NAME'=>'Nome Produto',
'LBL_LIST_AMOUNT'=>'Valor',
'LBL_LIST_DATE_CLOSED'=>'Previsão Fechamento',
'LBL_LIST_SALES_STAGE'=>'Estágio Vendas',

'LBL_OPPORTUNITY_NAME'=>'Nome Oportunidade:',
'LBL_ACCOUNT_NAME'=>'Nome Conta:',
'LBL_AMOUNT'=>'Montante(R$):',
'LBL_DATE_CLOSED'=>'Data Prevista Fechamento:',
'LBL_TYPE'=>'Tipo:',
'LBL_NEXT_STEP'=>'Próximo Passo:',
'LBL_LEAD_SOURCE'=>'Fonte Lead:',
'LBL_SALES_STAGE'=>'Estágio Vendas:',
'LBL_PROBABILITY'=>'Probabilidade (%):',
'LBL_DESCRIPTION'=>'Descrição:',
'LBL_OPPORTUNITY_INFORMATION'=>'Dados da Oportunidade:',
'LBL_DESCRIPTION_INFORMATION'=>'Descrição:',
'LBL_CUSTOM_INFORMATION'=>'Informação Customizada',

'LBL_NEW_FORM_TITLE'=>'Nova Oportunidade',

'ERR_DELETE_RECORD'=>"Defina um número de registro para deletar a Oportunidade.",
'LBL_TOP_OPPORTUNITIES'=>"Principais Oportunidades Abertas",

'NTC_REMOVE_OPP_CONFIRMATION'=>'Você tem certeza que deseja remover este Contato desta Oportunidade?',

'NTC_NONE_SCHEDULED'=>'Nada agendado.',

'LBL_SELECT_OPPOPTUNITY'=>'Selecione Oportunidade',
'LBL_GENERAL_INFORMATION'=>'Informação Geral',



//for v4 release added
'LBL_NEW_POTENTIAL'=>'Nova Oportunidade',
'LBL_POTENTIAL_TITLE'=>'Oportunidades',

'LBL_NEW_TASK'=>'Nova Tarefa',
'LBL_TASK_TITLE'=>'Tarefas',
'LBL_NEW_CALL'=>'Nova Chamada',
'LBL_CALL_TITLE'=>'Chamadas',
'LBL_NEW_MEETING'=>'Nova Reunião',
'LBL_MEETING_TITLE'=>'Reuniões',
'LBL_NEW_EMAIL'=>'Novo E-mail',
'LBL_EMAIL_TITLE'=>'E-mails',
'LBL_NEW_NOTE'=>'Novo Documento',
'LBL_NOTE_TITLE'=>'Documentos',

'LBL_NEW_ATTACHMENT'=>'Novo Anexo',
'LBL_ATTACHMENT_TITLE'=>'Anexos',

'LBL_NEW_CONTACT'=>'Novo Contato',
'LBL_CONTACT_TITLE'=>'Contatos',

//Added vtiger_fields after RC1 - Release
'LBL_ALL'=>'Todos',
'LBL_WON'=>'Vencido',
'LBL_LOST'=>'Perdido',
'LBL_VALUE_PROPOSITION'=>'Proposição Valor',
'LBL_PROSPECTING'=>'Prospectando',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Ferramentas Oportunidade',
//Added for 4GA
'Potential Name'=>'Nome Oportunidade',
'Amount'=>'Montante',
'Account Name'=>'Nome Conta',
'Currency'=>'Moeda',
'Expected Close Date'=>'Previsão Data Fechamento',
'Opportunity Type'=>'Tipo Oportunidade',
'Type'=>'Tipo',
'Next Step'=>'Próximo Passo',
'Lead Source'=>'Fonte Lead',
'Sales Stage'=>'Estágio de Vendas',
'Assigned To'=>'Responsável',
'Probability'=>'Probabilidade(%)',
'Campaign Source'=>'Fonte Campanha',
'Description'=>'Descrição',
'Created Time'=>'Data Criação',
'Modified Time'=>'Data Modificação',
//Added for 4.2 Release -- CustomView
'Potential'=>'Oportunidade',
'Expected Close'=>'Expectativa Fechamento',

//Added for Existing Picklist Strings

'Prospecting'=>'Prospectando',
'Qualification'=>'Qualificação',
'Needs Analysis'=>'Necessita Análise',
'Value Proposition'=>'Proposta Valor',
'Id. Decision Makers'=>'Identif. Decisor',
'Perception Analysis'=>'Análise Percepção',
'Proposal/Price Quote'=>'Proposta/Cotação',
'Negotiation/Review'=>'Negociação/Revisão',
'Closed Won'=>'Fechado Vencido',
'Closed Lost'=>'Fechado Perdido',

'Cold Call'=>'Cold Call',
'Existing Customer'=>'Cliente Existente',
'Self Generated'=>'Auto Gerado',
'Employee'=>'Empregado',
'Partner'=>'Parceiro',
'Public Relations'=>'Relações Públicas',
'Direct Mail'=>'Mala Direta',
'Conference'=>'Conferência',
'Trade Show'=>'Feira Negócios',
'Web Site'=>'Website',
'Word of mouth'=>'Boca-boca',
'Other'=>'Outro',

'--None--'=>'--Nada--',
'Existing Business'=>'Negócio Existente',
'New Business'=>'Novo Negócio',

// Added after 5.0.4 GA

// Module Sequence Numbering
'Potential No' => 'No. Oportunidade',
// END

'Related To' => 'Relacionado à', 
);

?>

==> vtigercrm-5.4.0.tgz: modules/Potentials/language/pt_br.lang.php <==
<?php
/*********************************************************************************
 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2
 * ("License"); You may not use this file except in compliance with the
 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL
 * Software distributed under the License is distributed on an  "AS IS"  basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific language governing rights and limitations under the License.
 * The Original Code is:  SugarCRM Open Source
 * The Initial Developer of the Original Code is SugarCRM, Inc.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;
 * All Rights Reserved.
 * Contributor(s): ______________________________________.
 ********************************************************************************/
/*********************************************************************************
 * $Header: /advent/projects/wesat/vtiger_crm/sugarcrm/modules/Potentials/language/en_us.lang.php,v 1.18 2005/04/28 14:05:53 ray Exp $
 * Description:  Defines the English language pack for the Potentials module.
 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.
 * All Rights Reserved.
 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese| 03/03/2012 |Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br
 ********************************************************************************/

$mod_strings = Array(
'LBL_MODULE_NAME'=>'Oportunidades',
'LBL_MODULE_TITLE'=>'Oportunidades: Principal',
'LBL_SEARCH_FORM_TITLE'=>'Pesquisar Oportunidade',
'LBL_LIST_FORM_TITLE'=>'Listar Oportunidade',
'LBL_OPPORTUNITY_NAME'=>'Nome Oportunidade:',
'LBL_OPPORTUNITY'=>'Oportunidade:',
'LBL_NAME'=>'Nome Oportunidade',
'LBL_INVITEE'=>'Contatos',
'LBL_LIST_OPPORTUNITY_NAME'=>'Oportunidade',
'LBL_LIST_ACCOUNT_NAME'=>'Nome Organização',
'LBL_PRODUCT_NAME'=>'Nome Produto',
'LBL_LIST_AMOUNT'=>'Valor',
'LBL_LIST_DATE_CLOSED'=>'Previsão Fechamento',
'LBL_LIST_SALES_STAGE'=>'Estágio Vendas',

'LBL_OPPORTUNITY_NAME'=>'Nome Oportunidade:',
'LBL_ACCOUNT_NAME'=>'Nome Organização:',
'LBL_AMOUNT'=>'Montante(R$):',
'LBL_DATE_CLOSED'=>'Data Prevista Fechamento:',
'LBL_TYPE'=>'Tipo:',
'LBL_NEXT_STEP'=>'Próximo Passo:',
'LBL_LEAD_SOURCE'=>'Fonte Lead:',
'LBL_SALES_STAGE'=>'Estágio Vendas:',
'LBL_PROBABILITY'=>'Probabilidade (%):',
'LBL_DESCRIPTION'=>'Descrição:',
'LBL_OPPORTUNITY_INFORMATION'=>'Dados da Oportunidade:',
'LBL_DESCRIPTION_INFORMATION'=>'Descrição:',
'LBL_CUSTOM_INFORMATION'=>'Informação Customizada',

'LBL_NEW_FORM_TITLE'=>'Nova Oportunidade',

'ERR_DELETE_RECORD'=>"Defina um número de registro para deletar a Oportunidade.",
'LBL_TOP_OPPORTUNITIES'=>"Principais Oportunidades Abertas",

'NTC_REMOVE_OPP_CONFIRMATION'=>'Você tem certeza que deseja remover este Contato desta Oportunidade?',

'NTC_NONE_SCHEDULED'=>'Nada agendado.',

'LBL_SELECT_OPPOPTUNITY'=>'Selecione Oportunidade',
'LBL_GENERAL_INFORMATION'=>'Informação Geral',



//for v4 release added
'LBL_NEW_POTENTIAL'=>'Nova Oportunidade',
'LBL_POTENTIAL_TITLE'=>'Oportunidades',

'LBL_NEW_TASK'=>'Nova Tarefa',
'LBL_TASK_TITLE'=>'Tarefas',
'LBL_NEW_CALL'=>'Nova Chamada',
'LBL_CALL_TITLE'=>'Chamadas',
'LBL_NEW_MEETING'=>'Nova Reunião',
'LBL_MEETING_TITLE'=>'Reuniões',
'LBL_NEW_EMAIL'=>'Novo E-mail',
'LBL_EMAIL_TITLE'=>'E-mails',
'LBL_NEW_NOTE'=>'Novo Documento',
'LBL_NOTE_TITLE'=>'Documentos',

'LBL_NEW_ATTACHMENT'=>'Novo Anexo',
'LBL_ATTACHMENT_TITLE'=>'Anexos',

'LBL_NEW_CONTACT'=>'Novo Contato',
'LBL_CONTACT_TITLE'=>'Contatos',

//Added vtiger_fields after RC1 - Release
'LBL_ALL'=>'Todos',
'LBL_WON'=>'Vencido',
'LBL_LOST'=>'Perdido',
'LBL_VALUE_PROPOSITION'=>'Proposição Valor',
'LBL_PROSPECTING'=>'Prospectando',

// Added for 4GA
'LBL_TOOL_FORM_TITLE'=>'Ferramentas Oportunidade',
//Added for 4GA
'Potential Name'=>'Nome Oportunidade',
'Amount'=>'Montante',
'Account Name'=>'Nome Organização',
'Currency'=>'Moeda',
'Expected Close Date'=>'Previsão Data Fechamento',
'Opportunity Type'=>'Tipo Oportunidade',
'Type'=>'Tipo',
'Next Step'=>'Próximo Passo',
'Lead Source'=>'Fonte Lead',
'Sales Stage'=>'Estágio de Vendas',
'Assigned To'=>'Responsável',
'Probability'=>'Probabilidade(%)',
'Campaign Source'=>'Fonte Campanha',
'Description'=>'Descrição',
'Created Time'=>'Data Criação',
'Modified Time'=>'Data Modificação',
//Added for 4.2 Release -- CustomView
'Potential'=>'Oportunidade',
'Expected Close'=>'Expectativa Fechamento',

//Added for Existing Picklist Strings

'Prospecting'=>'Prospectando',
'Qualification'=>'Qualificação',
'Needs Analysis'=>'Necessita Análise',
'Value Proposition'=>'Proposta Valor',
'Id. Decision Makers'=>'Identif. Decisor',
'Perception Analysis'=>'Análise Percepção',
'Proposal/Price Quote'=>'Proposta/Cotação',
'Negotiation/Review'=>'Negociação/Revisão',
'Closed Won'=>'Fechado Vencido',
'Closed Lost'=>'Fechado Perdido',

'Cold Call'=>'Cold Call',
'Existing Customer'=>'Cliente Existente',
'Self Generated'=>'Auto Gerado',
'Employee'=>'Empregado',
'Partner'=>'Parceiro',
'Public Relations'=>'Relações Públicas',
'Direct Mail'=>'Mala Direta',
'Conference'=>'Conferência',
'Trade Show'=>'Feira Negócios',
'Web Site'=>'Website',
'Word of mouth'=>'Boca-boca',
'Other'=>'Outro',

'--None--'=>'--Nada--',
'Existing Business'=>'Negócio Existente',
'New Business'=>'Novo Negócio',

// Added after 5.0.4 GA

// Module Sequence Numbering
'Potential No' => 'No. Oportunidade',
// END

'Related To' => 'Relacionado à',
'Potentials ID' => 'ID Oportunidades', 
);

?>
